pub struct ClientId { /* private fields */ }Expand description
An ID representing a Wayland client
The backend internally tracks which IDs are still valid, invalidates them when the client they represent
is disconnected. As such you can confidently compare two ClientId for equality, they will only compare
as equal if they both represent the same client.